
/**
 * Lösen eines Gleichungssystems mit zwei Unbekannten nach der Cramerschen Regel<br/>
 * Benutzung:<br/>
 * 
 *   <pre><code>
 *   |a  b||x|   |e|
 *   |    || | = | |
 *   |c  d||y|   |f|
 *   
 *   Cramer cramer = new Cramer();  
 *   cramer.berechne(a,b,c,d,e,f);  
 *   double x = cramer.getX();      
 *   double y = cramer.getY();      
 *   </code></pre>
 *   <br/>
 */
public class Cramer
{
    private double x,y;
    
    public double getX()
    {
        return x;
    }
    public double getY()
    {
        return y;
    }
    
    public void berechne(double a,double b,double c,double d,double e,double f)
    {
        Vektor v1 = new Vektor(a,c);
        Vektor v2 = new Vektor(b,d);
        Vektor v3 = new Vektor(e,f);
        
        Matrix m1 = new Matrix();
        Matrix m2 = new Matrix();
        Matrix m3 = new Matrix();
        
        m1.neu(v1,v2); 
        m2.neu(v3,v2); //für Dx
        m3.neu(v1,v3); //für Dy
        
        double D  = m1.berechneDeterminante();
        double Dx = m2.berechneDeterminante();
        double Dy = m3.berechneDeterminante();
        
        x = Dx/D;
        y = Dy/D;
    }
    
    public static void main(String[] args)
    {
        Cramer cramer = new Cramer();  
        cramer.berechne(3.0,4.0,2.0,1.0,11.0,4.0);  
        double x = cramer.getX();      
        double y = cramer.getY();              
        
        System.out.println("x="+x);
        System.out.println("y="+y);
    }
}
